@@ -59,6 +59,7 @@ slapos_controler = None
 def run(args):
   config = args[0]
   slapgrid = None
+  branch = config.get('branch', None)
   supervisord_pid_file = os.path.join(config['instance_root'], 'var', 'run',
         'supervisord.pid')
   subprocess.check_call([config['git_binary'],
@@ -81,20 +82,26 @@ def run(args):
 [buildout]
 extends = %(software_config_path)s
 
-[%(repository_name)s_repository]
+[%(repository_name)s]
 repository = %(repository_path)s
 """ %     {'software_config_path': os.path.join(repository_path,
                                             config['profile_url']),
       'repository_name': repository_name,
       'repository_path' : repository_path}
+    if branch is not None:
+      profile_content += "\nbranch %s" % branch
     custom_profile.write(profile_content)
     custom_profile.close()
   try:
     while True:
       # Make sure we have local repository
       if not os.path.exists(repository_path):
-        subprocess.check_call([config['git_binary'],
-                'clone', config['vcs_repository'], repository_path])
+        parameter_list = [config['git_binary'], 'clone',
+                          config['vcs_repository']]
+        if branch is not None:
+          parameter_list.extend(['-d',branch])
+        parameter_list.append(repository_path)
+        subprocess.check_call(parameter_list)
         # XXX this looks like to not wait the end of the command
       # Make sure we have local repository
       updater = Updater(repository_path, git_binary=config['git_binary'])
@@ -105,7 +112,6 @@ repository = %(repository_path)s
         continue
       previous_revision = revision
 
-
       print config
       portal_url = config['test_suite_master_url']
       test_result_path = None
